@@ -20,7 +20,7 @@ var nodes = require('../nodes')
  * @api public
  */
 
-module.exports = function hue(color, value){
+function hue(color, value){
   if (value) {
     var hslaColor = color.hsla;
     return hsla(
@@ -32,3 +32,5 @@ module.exports = function hue(color, value){
   }
   return component(color, new nodes.String('hue'));
 };
+hue.params = ['color', 'value'];
+module.exports = hue;
